%global pypi_name Pint


%if 0%{?fedora} || 0%{?rhel} > 7
%global with_python3 1
%endif

%bcond_with docs

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:           python-pint
Version:        0.9
Release:        1%{?dist}
Summary:        Physical quantities module

License:        BSD
URL:            https://github.com/hgrecco/pint
Source0:        https://pypi.python.org/packages/source/P/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

%description
Pint is Python module/package to define, operate and manipulate physical
quantities: the product of a numerical value and a unit of measurement.
It allows arithmetic operations between them and conversions from and
to different units.

It is distributed with a comprehensive list of physical units, prefixes
and constants.

%if %{with docs}
%package doc
Summary:        Documentation for the pint module
Provides:       python2-pint-doc = %{version}-%{release}

%description doc
Documentation for the pint module
%endif

#python3 subpackage
%if 0%{?with_python3}
%package -n python3-pint
Summary:        Physical quantities module
%{?python_provide:%python_provide python3-pint}

BuildRequires:  python3-devel
%if %{with docs}
BuildRequires:  python3-sphinx
%endif
BuildRequires:  python3-setuptools

%description -n python3-pint
Pint is Python module/package to define, operate and manipulate physical
quantities: the product of a numerical value and a unit of measurement.
It allows arithmetic operations between them and conversions from and
to different units.

It is distributed with a comprehensive list of physical units, prefixes
and constants.
%endif

%if %{with docs}
%if 0%{?with_python3}
%package -n python3-pint-doc
Summary:        Documentation for the pint module
%{?python_provide:%python_provide python3-pint-doc}
BuildRequires:  python3-sphinx

%description -n python3-pint-doc
Documentation for the pint module
%endif
%endif

%prep
%setup -q -n %{pypi_name}-%{version}

# Babel tests are not ready, see https://github.com/hgrecco/pint/issues/663
rm pint/testsuite/test_babel.py

%build

# generate html docs
%if %{with docs}
export PYTHONPATH="$( pwd ):$PYTHONPATH"
sphinx-build docs html
%endif

%if 0%{?with_python3}
%{__python3} setup.py build
%if %{with docs}
export PYTHONPATH="$( pwd ):$PYTHONPATH"
sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif
%endif

%install

%if 0%{?with_python3}
%{__python3} setup.py install --skip-build --root %{buildroot}
%endif

%check

%if 0%{?with_python3}
%{__python3} setup.py test
%endif

%if %{with docs}
%files doc
%doc html
%license docs/_themes/LICENSE
%endif

%if 0%{?with_python3}
%files -n python3-pint
%doc README
%license LICENSE
%{python3_sitelib}/pint
%{python3_sitelib}/%{pypi_name}-%{version}-py?.?.egg-info
%endif

%if %{with docs}
%if 0%{?with_python3}
%files -n python3-pint-doc
%doc html
%license docs/_themes/LICENSE
%endif
%endif

%changelog
* Wed Mar 06 2019 Shreshtha Joshi <shrjoshi@redhat.com> - 0.9-1
- Update to 0.9

* Thu Jan 17 2019 Shreshtha Joshi <shrjoshi@redhat.com> - 0.6-6.1
- RHEL8-isms

* Thu Nov 05 2015 Jon Schlueter <jschluet@redhat.com> 0.6-5.1
- revert to python-XXX with python2-XXX provides

* Sun Sep 06 2015 Matthias Runge <mrunge@redhat.com> - 0.6-5
- fix uppercase/lowercase naming, fix obsoletes

* Fri Sep 04 2015 Chandan Kumar <chkumar246@gmail.com> - 0.6-4
- Add python2 and python3 subpackages

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Dec 15 2014 Matthias Runge <mrunge@redhat.com> - 0.6-2
- change BR python-devel to python2-devel (rhbz#1173109)

* Thu Dec 11 2014 Matthias Runge <mrunge@redhat.com> - 0.6-1
- Initial package.
